Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(456)

Unified Diff: mandoline/ui/desktop_ui/browser_window.h

Issue 1406153004: components/mus/public/interfaces View => Window (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Yet another rebase Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mandoline/ui/desktop_ui/browser_manager.h ('k') | mandoline/ui/desktop_ui/browser_window.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mandoline/ui/desktop_ui/browser_window.h
diff --git a/mandoline/ui/desktop_ui/browser_window.h b/mandoline/ui/desktop_ui/browser_window.h
index 2824c424ad1a928ab97f97a211345d69af4ca785..c3606fe91b30a8e45bc7c7f1d85a1b65f33c81ec 100644
--- a/mandoline/ui/desktop_ui/browser_window.h
+++ b/mandoline/ui/desktop_ui/browser_window.h
@@ -7,7 +7,7 @@
#include "components/mus/public/cpp/window_tree_connection.h"
#include "components/mus/public/cpp/window_tree_delegate.h"
-#include "components/mus/public/interfaces/view_tree_host.mojom.h"
+#include "components/mus/public/interfaces/window_tree_host.mojom.h"
#include "components/web_view/public/cpp/web_view.h"
#include "components/web_view/public/interfaces/web_view.mojom.h"
#include "mandoline/ui/desktop_ui/find_bar_delegate.h"
@@ -22,7 +22,6 @@
namespace mojo {
class ApplicationConnection;
class Shell;
-class View;
}
namespace mandoline {
@@ -33,7 +32,7 @@ class ProgressView;
class ToolbarView;
class BrowserWindow : public mus::WindowTreeDelegate,
- public mojo::ViewTreeHostClient,
+ public mus::mojom::WindowTreeHostClient,
public web_view::mojom::WebViewClient,
public ViewEmbedder,
public mojo::InterfaceFactory<ViewEmbedder>,
@@ -41,7 +40,7 @@ class BrowserWindow : public mus::WindowTreeDelegate,
public FindBarDelegate {
public:
BrowserWindow(mojo::ApplicationImpl* app,
- mojo::ViewTreeHostFactory* host_factory,
+ mus::mojom::WindowTreeHostFactory* host_factory,
BrowserManager* manager);
void LoadURL(const GURL& url);
@@ -61,7 +60,7 @@ class BrowserWindow : public mus::WindowTreeDelegate,
void OnEmbed(mus::Window* root) override;
void OnConnectionLost(mus::WindowTreeConnection* connection) override;
// Overridden from ViewTreeHostClient:
void OnAccelerator(uint32_t id, mojo::EventPtr event) override;
// Overridden from web_view::mojom::WebViewClient:
@@ -98,8 +97,8 @@ class BrowserWindow : public mus::WindowTreeDelegate,
mojo::ApplicationImpl* app_;
scoped_ptr<views::AuraInit> aura_init_;
- mojo::ViewTreeHostPtr host_;
- mojo::Binding<ViewTreeHostClient> host_client_binding_;
+ mus::mojom::WindowTreeHostPtr host_;
+ mojo::Binding<WindowTreeHostClient> host_client_binding_;
BrowserManager* manager_;
ToolbarView* toolbar_view_;
ProgressView* progress_bar_;
@@ -61,7 +60,7 @@ class BrowserWindow : public mus::WindowTreeDelegate,
void OnEmbed(mus::Window* root) override;
void OnConnectionLost(mus::WindowTreeConnection* connection) override;
- // Overridden from ViewTreeHostClient:
+ // Overridden from WindowTreeHostClient:
void OnAccelerator(uint32_t id, mojo::EventPtr event) override;
// Overridden from web_view::mojom::WebViewClient:
« no previous file with comments | « mandoline/ui/desktop_ui/browser_manager.h ('k') | mandoline/ui/desktop_ui/browser_window.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698